@@ -10,12 +10,13 @@ import json
 import logging
 from collections.abc import Awaitable, Callable
 from dataclasses import dataclass
-from typing import Any, Final
+from typing import Any
 
 import aiohttp
 import websockets
 
-from sn2.json_model import DeviceInformation, Settings
+from .constants import IN_WALL_MODELS, LIGHT_MODELS, PLUG_MODELS, SWITCH_MODELS
+from .data_model import InformationData, Settings
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -47,78 +48,6 @@ class NotConnectedError(Exception):
         super().__init__(self.message)
 
 
-SWITCH_MODELS: Final = ["WBR-01"]
-PLUG_MODELS: Final = ["WPR-01", "WPO-01"]
-LIGHT_MODELS: Final = ["WBD-01", "WPD-01"]
-
-
-@dataclass
-class InformationData:
-    """
-    Device information data container.
-
-    Attributes
-    ----------
-    dimmable : bool
-        Whether the device supports dimming.
-    model : str | None
-        The hardware model of the device.
-    sw_version : str | None
-        The software version of the device.
-    hw_version : str | None
-        The hardware version of the device.
-    name : str | None
-        The name of the device.
-    wifi_dbm : int | None
-        The WiFi signal strength in dBm.
-    wifi_ssid : str | None
-        The WiFi SSID the device is connected to.
-    unique_id : str | None
-        The unique identifier of the device.
-
-    """
-
-    dimmable: bool = False
-    model: str | None = None
-    sw_version: str | None = None
-    hw_version: str | None = None
-    name: str | None = None
-    wifi_dbm: int | None = None
-    wifi_ssid: str | None = None
-    unique_id: str | None = None
-
-    @staticmethod
-    def convert_device_information_to_data(
-        info: DeviceInformation,
-    ) -> "InformationData":
-        """
-        Create InformationData from a DeviceInformation object.
-
-        Parameters
-        ----------
-        info : DeviceInformation
-            The device information object to convert.
-
-        Returns
-        -------
-        InformationData
-            A new InformationData instance populated with the device information.
-
-        """
-        d = InformationData()
-        if info.hwm in LIGHT_MODELS:
-            d.dimmable = True
-        d.model = info.hwm
-        d.sw_version = info.nswv
-        d.hw_version = str(info.nhwv)
-        d.name = info.n
-        d.wifi_dbm = info.wr
-        d.wifi_ssid = info.ws
-        d.unique_id = info.lcu
-
-        return d
-
-
 @dataclass
 class ConnectionStatus:
     """Connection status event."""
@@ -247,6 +176,48 @@ class SettingsUpdate:
 UpdateEvent = ConnectionStatus | InformationUpdate | SettingsUpdate | StateChange
 
 
+@staticmethod
+def _is_version_compatible(version: str | None, min_version: str) -> bool:
+    """Check if a version string meets minimum version requirements."""
+    if version is None:
+        return False
+    if min_version is None:
+        msg = "min_version needs to be set when comparing"
+        raise ValueError(msg)
+    try:
+        # Clean up version strings - remove any pre-release indicators
+        # Example: "0.9.5-beta.2" becomes "0.9.5"
+        clean_version = version.split("-")[0].split("+")[0]
+        clean_min_version = min_version.split("-")[0].split("+")[0]
+
+        version_parts = [int(part) for part in clean_version.split(".")]
+        min_version_parts = [int(part) for part in clean_min_version.split(".")]
+
+        while len(version_parts) < len(min_version_parts):
+            version_parts.append(0)
+        while len(min_version_parts) < len(version_parts):
+            min_version_parts.append(0)
+
+        # Compare version components
+        for v, m in zip(version_parts, min_version_parts, strict=False):
+            if v > m:
+                return True
+            if v < m:
+                return False
+
+        # All components are equal, so versions are equal
+
+    except (ValueError, IndexError):
+        # If parsing fails, log the error and reject the version
+        _LOGGER.exception(
+            "Error parsing version strings '%s' and '%s'",
+            version,
+            min_version,
+        )
+        return False
+    return True
+
+
 class Device:
     """
     Represents a client for SystemNexa2 device integration.
@@ -255,49 +226,6 @@ class Device:
 
     """
 
-    @staticmethod
-    def _is_version_compatible(version: str | None, min_version: str) -> bool:
-        """Check if a version string meets minimum version requirements."""
-        if version is None:
-            return False
-        if min_version is None:
-            msg = "min_version needs to be set when comparing"
-            raise ValueError(msg)
-        try:
-            # Clean up version strings - remove any pre-release indicators
-            # Example: "0.9.5-beta.2" becomes "0.9.5"
-            clean_version = version.split("-")[0].split("+")[0]
-            clean_min_version = min_version.split("-")[0].split("+")[0]
-
-            # Split version strings into components
-            version_parts = [int(part) for part in clean_version.split(".")]
-            min_version_parts = [int(part) for part in clean_min_version.split(".")]
-
-            # Pad shorter lists with zeros
-            while len(version_parts) < len(min_version_parts):
-                version_parts.append(0)
-            while len(min_version_parts) < len(version_parts):
-                min_version_parts.append(0)
-
-            # Compare version components
-            for v, m in zip(version_parts, min_version_parts, strict=False):
-                if v > m:
-                    return True
-                if v < m:
-                    return False
-
-            # All components are equal, so versions are equal
-
-        except (ValueError, IndexError):
-            # If parsing fails, log the error and reject the version
-            _LOGGER.exception(
-                "Error parsing version strings '%s' and '%s'",
-                version,
-                min_version,
-            )
-            return False
-        return True
-
     @staticmethod
     def is_device_supported(
         model: str | None, device_version: str | None
@@ -312,6 +240,7 @@ class Device:
             model not in SWITCH_MODELS
             and model not in LIGHT_MODELS
             and model not in PLUG_MODELS
+            and model not in IN_WALL_MODELS
         ):
             return False, f"Unsupported model: {model}"
 
@@ -320,7 +249,7 @@ class Device:
             return False, "Missing firmware version"
 
         # Version check - require at least 0.9.5
-        if not Device._is_version_compatible(device_version, min_version="0.9.5"):
+        if not _is_version_compatible(device_version, min_version="0.9.5"):
             return (
                 False,
                 f"Incompatible firmware version {device_version} (min required: 0.9.5)",
@@ -331,31 +260,27 @@ class Device:
     def __init__(
         self,
         host: str,
+        initial_settings: list[Setting],
+        initial_info_data: InformationData,
         on_update: Callable[[UpdateEvent], Awaitable[None] | None] | None = None,
     ) -> None:
-        """
-        Initialize the Device client.
-
-        Args:
-            host (str): The host address of the device.
-            on_update (Callable[[UpdateEvent], Awaitable[None] | None] | None):
-                Callback for device update events.
-
-        """
+        """Initialize the Device client. Should not be used see initiate_device."""
         self.host = host
         self._trying_to_connect = False
         self._websocket: websockets.ClientConnection | None = None
         self._ws_task: asyncio.Task[None] | None = None
-        self._login_key = None
-        self._version: str | None = None
-        self.info_data: InformationData | None = None
-        self.initialized = False
-        self.settings: list[Setting] = []
+        self._version = initial_info_data.sw_version
+        self.info_data = initial_info_data
+        self.settings = initial_settings
 
         # Callbacks
         self._on_update = on_update
 
-    async def initialize(self) -> None:
+    @staticmethod
+    async def initiate_device(
+        host: str,
+        on_update: Callable[[UpdateEvent], Awaitable[None] | None] | None = None,
+    ) -> "Device":
         """
         Initialize the device by fetching settings and information.
 
@@ -366,13 +291,14 @@ class Device:
 
         """
         try:
-            settings = await self.get_settings()
-            info = await self.get_info()
-            self._version = info.information.sw_version
-            if info and settings:
-                self.settings = settings
-                self.info_data = info.information
-                self.initialized = True
+            settings = await Device._get_settings(host)
+            info = await Device._get_info(host)
+            return Device(
+                host=host,
+                initial_settings=settings,
+                initial_info_data=info.information,
+                on_update=on_update,
+            )
         except Exception as e:
             msg = "Failed to initialize device"
             raise DeviceInitializationError(msg) from e
@@ -477,18 +403,15 @@ class Device:
                     await self._emit(StateChange(state_value))
                 case "information":
                     info_message = data.get("value")
-                    information = DeviceInformation(**info_message)
-                    _LOGGER.debug("information received %s", information)
+                    _LOGGER.debug("information received %s", info_message)
                     await self._emit(
                         InformationUpdate(
-                            InformationData.convert_device_information_to_data(
-                                information
-                            )
+                            InformationData.from_device_dict(info_message)
                         )
                     )
                 case "settings":
                     settings = data.get("value")
-                    settings = Settings(**settings)
+                    settings = Settings.from_device_dict(settings)
                     await self._emit(
                         SettingsUpdate(settings=await self._parse_settings(settings))
                     )
@@ -528,14 +451,14 @@ class Device:
 
     async def turn_off(self) -> None:
         """Turn off the device."""
-        if self._is_version_compatible(self._version, "1.1.8"):
+        if _is_version_compatible(self._version, "1.1.8"):
             await self.send_command({"type": "state", "on": False})
         else:
             await self.send_command({"type": "state", "value": 0})
 
     async def turn_on(self) -> None:
         """Turn on the device."""
-        if self._is_version_compatible(self._version, "1.1.8"):
+        if _is_version_compatible(self._version, "1.1.8"):
             await self.send_command({"type": "state", "on": True})
         else:
             await self.send_command({"type": "state", "value": -1})
@@ -577,7 +500,7 @@ class Device:
 
         for attempt in range(1, retries + 1):
             try:
-                _LOGGER.info(
+                _LOGGER.debug(
                     "Sending command to %s (attempt %d/%d): %s",
                     self.host,
                     attempt,
@@ -617,31 +540,22 @@ class Device:
                 )
                 await self._emit(ConnectionStatus(connected=False))
             else:
-                _LOGGER.debug(
+                _LOGGER.info(
                     "Command %s sent successfully to %s", command_str, self.host
                 )
                 return
 
-            # Wait a bit before retrying (exponential backoff)
             if attempt < retries:
-                await asyncio.sleep(0.5 * (2**attempt))
+                await asyncio.sleep(0.5 * (2**attempt))  # (exponential backoff)
 
-        # If we get here, all retries failed
         _LOGGER.error(
             "Failed to send command to %s after %d attempts", self.host, retries
         )
         if last_exception:
             raise last_exception
 
-    async def is_supported(self) -> bool:
-        """Check if the device is supported based on model and firmware version."""
-        info = await self.get_info()
-        supported, _ = Device.is_device_supported(
-            model=info.information.model, device_version=info.information.sw_version
-        )
-        return supported
-
-    async def _parse_settings(self, settings: Settings) -> list[Setting]:
+    @staticmethod
+    async def _parse_settings(settings: Settings) -> list[Setting]:
         settings_list: list[Setting] = []
         if settings.disable_433 is not None:
             settings_list.append(
@@ -694,34 +608,42 @@ class Device:
                 session.post(url, json=settings) as response,
             ):
                 response.raise_for_status()
-
-                _LOGGER.error("Updated settings at %s with %s", url, settings)
-        except Exception:
+                _LOGGER.debug("Updated settings at %s with %s", url, settings)
+        except:
             _LOGGER.exception("Failed to update settings at %s", url)
             raise
 
-    async def get_settings(self) -> list[Setting]:
+    @staticmethod
+    async def _get_settings(host: str) -> list[Setting]:
         """Fetch device settings via REST API."""
-        url = f"http://{self.host}:3000/settings"
+        url = f"http://{host}:3000/settings"
         try:
             async with aiohttp.ClientSession() as session, session.get(url) as response:
+                response.raise_for_status()
                 json_resp = await response.json()
-                return await self._parse_settings(Settings(**json_resp))
+                return await Device._parse_settings(
+                    Settings.from_device_dict(json_resp)
+                )
         except Exception:
             _LOGGER.exception("Failed to fetch settings from %s", url)
             raise
 
-    async def get_info(self) -> InformationUpdate:
-        """Fetch device information via REST API."""
-        url = f"http://{self.host}:3000/info"
+    async def get_settings(self) -> list[Setting]:
+        """Fetch device settings via REST API."""
+        return await self._get_settings(self.host)
+
+    @staticmethod
+    async def _get_info(host: str) -> InformationUpdate:
+        url = f"http://{host}:3000/info"
         try:
             async with aiohttp.ClientSession() as session, session.get(url) as response:
                 response.raise_for_status()
-                information = DeviceInformation(**await response.json())
-                self.info_data = InformationData.convert_device_information_to_data(
-                    information
-                )
-                return InformationUpdate(self.info_data)
+                info_data = InformationData.from_device_dict(await response.json())
+                return InformationUpdate(info_data)
         except:
             _LOGGER.exception("Failed to fetch device information from %s:", url)
             raise
+
+    async def get_info(self) -> InformationUpdate:
+        """Fetch device information via REST API."""
+        return await self._get_info(self.host)
